@@ -1,7 +1,7 @@
 """
 Type annotations for s3outposts service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client/)
 
 Usage::
 
@@ -14,13 +14,17 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, Mapping, Type
+from typing import Any, Dict, Mapping, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
 from .literals import EndpointAccessTypeType
-from .paginator import ListEndpointsPaginator
-from .type_defs import CreateEndpointResultTypeDef, ListEndpointsResultTypeDef
+from .paginator import ListEndpointsPaginator, ListSharedEndpointsPaginator
+from .type_defs import (
+    CreateEndpointResultTypeDef,
+    ListEndpointsResultTypeDef,
+    ListSharedEndpointsResultTypeDef,
+)
 
 if sys.version_info >= (3, 9):
     from typing import Literal
@@ -51,7 +55,7 @@ class Exceptions:
 class S3OutpostsClient(BaseClient):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client/)
     """
 
     meta: ClientMeta
@@ -62,7 +66,7 @@ class S3OutpostsClient(BaseClient):
         S3OutpostsClient exceptions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#exceptions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client/#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
@@ -70,7 +74,7 @@ class S3OutpostsClient(BaseClient):
         Check if an operation can be paginated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#can_paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client/#can_paginate)
         """
 
     def create_endpoint(
@@ -83,20 +87,18 @@ class S3OutpostsClient(BaseClient):
         CustomerOwnedIpv4Pool: str = ...
     ) -> CreateEndpointResultTypeDef:
         """
-        Amazon S3 on Outposts Access Points simplify managing data access at scale for
-        shared datasets in S3 on Outposts.
+        Creates an endpoint and associates it with the specified Outpost.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Client.create_endpoint)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#create_endpoint)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client/#create_endpoint)
         """
 
     def delete_endpoint(self, *, EndpointId: str, OutpostId: str) -> None:
         """
-        Amazon S3 on Outposts Access Points simplify managing data access at scale for
-        shared datasets in S3 on Outposts.
+        Deletes an endpoint.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Client.delete_endpoint)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#delete_endpoint)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client/#delete_endpoint)
         """
 
     def generate_presigned_url(
@@ -110,22 +112,42 @@ class S3OutpostsClient(BaseClient):
         Generate a presigned url given a client, its method, and arguments.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#generate_presigned_url)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client/#generate_presigned_url)
         """
 
     def list_endpoints(
         self, *, NextToken: str = ..., MaxResults: int = ...
     ) -> ListEndpointsResultTypeDef:
         """
-        Amazon S3 on Outposts Access Points simplify managing data access at scale for
-        shared datasets in S3 on Outposts.
+        Lists endpoints associated with the specified Outpost.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Client.list_endpoints)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#list_endpoints)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client/#list_endpoints)
         """
 
+    def list_shared_endpoints(
+        self, *, OutpostId: str, NextToken: str = ..., MaxResults: int = ...
+    ) -> ListSharedEndpointsResultTypeDef:
+        """
+        Lists all endpoints associated with an Outpost that has been shared by Amazon
+        Web Services Resource Access Manager (RAM).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Client.list_shared_endpoints)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client/#list_shared_endpoints)
+        """
+
+    @overload
     def get_paginator(self, operation_name: Literal["list_endpoints"]) -> ListEndpointsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client/#get_paginator)
+        """
+
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_shared_endpoints"]
+    ) -> ListSharedEndpointsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client/#get_paginator)
         """
