@@ -1,7 +1,7 @@
 """
 Type annotations for s3outposts service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/literals/)
 
 Usage::
 
@@ -23,14 +23,20 @@ __all__ = (
     "EndpointAccessTypeType",
     "EndpointStatusType",
     "ListEndpointsPaginatorName",
+    "ListSharedEndpointsPaginatorName",
+    "S3OutpostsServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
 EndpointAccessTypeType = Literal["CustomerOwnedIp", "Private"]
 EndpointStatusType = Literal["Available", "Deleting", "Pending"]
 ListEndpointsPaginatorName = Literal["list_endpoints"]
+ListSharedEndpointsPaginatorName = Literal["list_shared_endpoints"]
+S3OutpostsServiceName = Literal["s3outposts"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -62,6 +68,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -148,6 +155,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -184,6 +192,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -248,6 +257,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -332,4 +342,39 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
-PaginatorName = Literal["list_endpoints"]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
+PaginatorName = Literal["list_endpoints", "list_shared_endpoints"]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
